@@ -1,10 +1,12 @@
 # -*- mode: python; coding: utf-8 -*-
 
+from __future__ import with_statement
+
 import os, sys, string, stat
 import glob
 import subprocess as subp
 import optparse
-import logging #, logging.handlers
+import logging
 import time
 import select
 import signal
@@ -14,41 +16,18 @@ import socket
 import StringIO
 from functools import partial
 
-logging.basicConfig()
-
 from atheist.const import *
 from atheist.utils import *
+import atheist.log
+from atheist.gvar import Log
 
-"""
-Verbosity level:
+from pyarco.Type import Record, SortedDict, merge_uniq
+from pyarco.Pattern import Singleton
+from pyarco.Thread import ThreadFunc
+from pyarco.UI import ellipsis, high, cout
+from pyarco.Conio import *
 
-0:
-[  OK  ]( 0) samples/test1.test              ls
-[ FAIL ]( 2) samples/test1.test              ls na
-Total: 0.03s - 1/2
 
-1: INFO
-samples/test1.test: 2 tests
-[  OK  ]( 0) samples/test1.test              ls
-[ FAIL ]( 2) samples/test1.test              ls na
-Total: 0.54s - 1/2
-
-2: DEBUG
-samples/test1.test loading
-samples/test1.test: 2 tests
-Executing <Test 'test1.test' - 'ls'>
-<Test 'test1.test' - 'ls'> process ends
-Executing <Test 'test1.test' - 'ls na'>
-<Test 'test1.test' - 'ls na'> process ends
-[  OK  ]( 0) samples/test1.test              ls
-[ FAIL ]( 2) samples/test1.test              ls na
-Total: 0.03s - 1/2
-"""
-
-class LoggingFormatter(logging.Formatter):
-    def format(self, record):
-        record.levelinitial = record.levelname[0]*2
-        return logging.Formatter.format(self, record)
 
 
 def check_type(val, cls):
@@ -56,33 +35,24 @@ def check_type(val, cls):
         raise TypeError(("A %s is required, not %s." % \
               (cls.__name__, val.__class__.__name__)))
 
+    return val
+
 
 def pretty(value):
-    term = os.getenv('TERM')
-    cterm = os.getenv('COLORTERM')
 
-    if cterm or 'color' in term or 'xterm' == term:
-        just = 12
-        RESULT_STR = {\
-            FAIL:    IRED        + "FAIL" + NORM,
-            OK:      GREEN       + " OK " + NORM,
-            NOEXEC:  GREY        + " -- " + NORM,
-            ERROR:   BOLD + IRED + " !! " + NORM,
-            UNKNOWN: GREY        + " ?? " + NORM,
-            TODO:    PURPLE      + "ToDo" + NORM,
-            mild_FAIL: RED + "fail" + NORM}
-    else:
-        just = 4
-        RESULT_STR = {\
-            FAIL:            "FAIL",
-            OK:              " OK ",
-            NOEXEC:          " -- ",
-            ERROR:           " !! ",
-            UNKNOWN:         " ?? ",
-            TODO:            "ToDo",
-            mild_FAIL: "fail"}
+    just = 12
+    RESULT_STR = {\
+        FAIL:      [LIGHT_RED   , "FAIL"],
+        OK:        [GREEN       , " OK "],
+        NOEXEC:    [GREY        , " -- "],
+        ERROR:     [BOLD , LIGHT_RED , " !! "],
+        UNKNOWN:   [GREY        , " ?? "],
+        TODO:      [PURPLE      , "ToDo"],
+        mild_FAIL: [RED         , "fail"]}
 
-    return "[%s]" % RESULT_STR[value].center(just)
+    return "[%s]" % cout(*RESULT_STR[value]+[NORM])
+
+#    return "[%s]" % RESULT_STR[value].center(just)
 
 
 def file_template():
@@ -106,6 +76,19 @@ def file_template():
 '''
 
 
+def exec_file(fname, _global=None, _local=None, template={}):
+    try:
+        with file(fname) as fd:
+            script = string.Template(fd.read()).safe_substitute(template)
+
+        code = compile(script, fname, 'exec')
+        exec(code) in _global, _local  # EXEC USER FILE
+
+    except Exception, e:
+        print_exc(traceback.format_exc())
+        Log.error("Errors in the testcase definition '%s'" % fname)
+        sys.exit(1)
+
 
 class Public:
     "Base class for classes available for the client tasks"
@@ -176,13 +159,18 @@ class ConsoleSummaryReporter(SummaryReporter):
 
     def build_taskcase(self, taskcase):
 
-        TESTCASE_FORMAT = '{result} Test case: {path}'
+#        TESTCASE_FORMAT = '{result} TaskCase: {path}'
+#        self.report.append(
+#            TESTCASE_FORMAT.format(
+#                result = pretty(taskcase.result),
+#                path   = compath(taskcase.fname)
+#                ))
+
+#        print taskcase.fname
+        self.report.append("%s TaskCase: %s" %  (
+                pretty(taskcase.result),
+                compath(taskcase.fname)))
 
-        self.report.append(
-            TESTCASE_FORMAT.format(
-                result = pretty(taskcase.result),
-                path   = compath(taskcase.fname)
-                ))
 
         if taskcase.result in [OK,NOEXEC] and self.config.report_detail < 2:
             return
@@ -196,25 +184,36 @@ class ConsoleSummaryReporter(SummaryReporter):
         cmd = task.cmd if hasattr(task, 'cmd') else ''
 
         if task.desc:
-            cmd_desc = '%s | %s' % (ellipsis(cmd, self.width*0.25, True),
-                                    task.desc)
+            cmd_desc = '%s | %s' % (ellipsis(cmd, self.width*0.25, True), task.desc)
         else:
             cmd_desc = ellipsis(cmd, self.width*0.75)
 
 
-        TASK_SUMMARY = u"{result} {tree} {type}{mode}{index:<3} ({retcode:>2}:{expected:2})  {desc}"
+#        TASK_SUMMARY = u"{result} {tree} {type}-{index:<3}{mode}({retcode:>2}:{expected:2})  {desc}"
+
+#        self.report.append(
+#            TASK_SUMMARY.format(
+#                result   = pretty(task.result),
+#                tree     = tree,
+#                retcode  = retcode,
+#                expected = task.expected,
+#                mode     = task.get_mode(),
+#                type     = task.acro,
+#                index    = task.indx,
+#                desc     = cmd_desc
+#                ))
+
+
+        self.report.append("%s %s %s-%-3s%s(%2s:%2s)  %s" % (
+                pretty(task.result),
+                tree,
+                task.acro,
+                task.indx,
+                task.get_mode(),
+                retcode,
+                task.expected,
+                cmd_desc))
 
-        self.report.append(
-            TASK_SUMMARY.format(
-                result   = pretty(task.result),
-                tree     = tree,
-                retcode  = retcode,
-                expected = task.expected,
-                mode     = task.get_mode(),
-                type     = task.initial,
-                index    = task.indx,
-                desc     = cmd_desc
-                ))
 
         if (self.config.report_detail > 2 or task.result != OK) and \
                 isinstance(task, CompositeTask):
@@ -231,18 +230,23 @@ class ConsoleSummaryReporter(SummaryReporter):
 
     def build_condition(self, cond, conn, tree, task):
 
-        CONDITION_SUMMARY = u"{value} {tree} {kind:<4} {name} {info}"
+#        CONDITION_SUMMARY = u"{value} {tree} {kind:<4} {name} {info}"
+#        self.report.append(
+#            CONDITION_SUMMARY.format(
+#                value  = pretty(cond.value),
+#                tree   = tree,
+#                kind   = 'pre: ' if cond in task.pre else 'post:',
+#                name   = cond.name,
+#                info   = cond.basic_info()
+#                ))
 
-        value_len = len(pretty(cond.value))
+        self.report.append("%s %s %s %s %s" % (
+                pretty(cond.value),
+                tree,
+                'pre: ' if cond in task.pre else 'post:',
+                cond.name,
+                cond.basic_info()))
 
-        self.report.append(
-            CONDITION_SUMMARY.format(
-                value  = pretty(cond.value),
-                tree   = tree,
-                kind   = 'pre: ' if cond in task.pre else 'post:',
-                name   = cond.name,
-                info   = cond.basic_info()
-                ))
 
 
 def tree_draw(container, cb, conn='', args=[]):
@@ -308,7 +312,7 @@ class TypedList(list):
         Log.error("Use operator += instead")
 
     def __iadd__(self, val):
-        if isinstance(val, list):
+        if isinstance(val, list) or isinstance(val, tuple):
             for i in val: self += i
             return self
 
@@ -373,7 +377,7 @@ class Condition:
     def before(self, task):
         """ Executed just BEFORE task execution """
 
-        print "%s - %s" % (self, task)
+#        print "%s - %s" % (self, task)
         if self.task is not None and task is not self.task:
             Log.error("Conditions can not be shared: %s in %s" % (self, self.task))
             sys.exit(1)
@@ -436,7 +440,7 @@ class Callback(Condition, Public):
 
         except Exception, e:
             Log.error("%s: %s" % (self.__class__.__name__, e))
-            print_exc(traceback.format_exc())
+            print_exc(traceback.format_exc(limit=1))
 
         return False
 
@@ -483,12 +487,19 @@ class DirExists(FileExists, Public):
 
 
 class FileContains(Condition, Public):
-    def __init__(self, data, fname=None, times=1):
+    def __init__(self, data, fname=None,  strip='', whole=False, times=1):
         self.fname = fname
-        self.times = times
+        self.times = check_type(times, int)
+        self.whole = check_type(whole, bool)
+        self.strip = check_type(strip, str)
+
+        if whole:
+            assert isinstance(data, str), "In whole-mode, data must be a string"
+
         self.contains = self.check_contains(data)
         Condition.__init__(self)
 
+
     def before(self, task):
 #        print "setting task <<<<<< %s" % self
 
@@ -539,8 +550,13 @@ class FileContains(Condition, Public):
             Log.error(e)
             return ERROR
 
+        if self.strip: fcontent = fcontent.strip(self.strip)
+
+        if self.whole:
+            return fcontent == self.contains[0]
+
         return all([fcontent.count(x) >= self.times for x in self.contains])
-        #return all([x in fcontent for x in self.contains])
+
 
     def basic_info(self):
         return "'%s' (%s) content:'%s'" % (self.fname, self.times,
@@ -589,32 +605,6 @@ class FileIsNewerThan(Condition, Public):
         return "'%s' is newer than '%s'" % (self.fname1, self.fname2)
 
 
-class OpenPort(Condition, Public):
-    def __init__(self, port, host='localhost', proto='tcp'):
-        assert proto in ['tcp','udp']
-        assert isinstance(port , int) and 0 < port < 65535
-        Condition.__init__(self)
-
-        self.proto = proto
-        self.port = port
-        self.host = host
-
-    def run(self):
-        if self.host == 'localhost':
-            self.cmd = 'fuser -n %s %s > /dev/null 2> /dev/null' % \
-                       (self.proto, self.port)
-        else:
-            self.cmd = 'nmap -p%s %s | grep "%s/%s open" > /dev/null' % \
-                       (self.port, self.host, self.port, self.proto)
-        return os.system(self.cmd) == 0
-
-    def basic_info(self):
-        return "'%s %s/%s'" % (self.host, self.proto, self.port)
-
-    def more_info(self):
-        return "cmd: %s" % self.cmd
-
-
 class ProcessRunning(Condition, Public):
     def __init__(self, pid):
         assert isinstance(pid, int)
@@ -730,10 +720,6 @@ class RemoteTestFactory(Public):
 
 
 
-DFL_TIMEOUT = 5
-DFL_SIGNAL = signal.SIGKILL
-
-
 class BufFile:
 
     def __init__(self, fd):
@@ -803,7 +789,8 @@ class FileWrapper:
 
 class Task(Record):
 
-    allows = ['tid', 'cwd', 'delay', 'desc', 'expected', 'must_fail', 'template',
+    acro = 'Task'
+    allows = ['tid', 'cwd', 'delay', 'desc', 'dirty', 'expected', 'must_fail', 'template',
               'save_stdout', 'save_stderr', 'stderr', 'stdout', 'todo']
     forbid = []
 
@@ -816,7 +803,7 @@ class Task(Record):
         for k,v in _dict.items():
             assert task_attrs.has_key(k), "'%s' is not a valid keyword" % k
             assert k in cls.allows, \
-            "'%s' is not a allowed keyword for '%s'" % (k, cls.__name__)
+            "'%s' is not an allowed keyword for '%s'" % (k, cls.__name__)
 
             check_type(v, task_attrs[k].type_)
 
@@ -880,10 +867,9 @@ class Task(Record):
             return # the logger already exists
 
         term = logging.StreamHandler()
-        term.setFormatter(\
-            LoggingFormatter(\
+        term.setFormatter(log.XXLoggingFormatter(\
                 self.mgr.config.timetag + '[%(levelinitial)s] %(name)s: %(message)s',
-                LOG_DATEFORMAT))
+                log.DATEFORMAT))
         term.setLevel(self.mgr.config.loglevel)
         self.log.setLevel(self.mgr.config.loglevel)
         self.log.addHandler(term)
@@ -950,6 +936,16 @@ class Task(Record):
     def description(self):
         return  "%s:%s" % (self.name, self.desc)
 
+    @property
+    def name(self):
+        return self.initial + str(self.indx)
+
+    @property
+    def initial(self):
+        retval = self.__class__.__name__[0]
+        return retval
+
+
     def describe(self, pre_keys=[]):
         self.setup()
 
@@ -997,16 +993,6 @@ class Task(Record):
         return ''
 
 
-    @property
-    def name(self):
-        return self.initial + str(self.indx)
-
-    @property
-    def initial(self):
-        retval = self.__class__.__name__[0]
-        return retval
-
-
     def clone(self):
         d = self.kargs
         d['desc'] = '(copy of %s) %s' % (self.name, d['desc'])
@@ -1020,6 +1006,11 @@ class Task(Record):
 
 
     def do_exec_task(self):
+        # key-val sanity
+        if self.dirty and not self.gen:
+            self.log.warning("'dirty' with empty 'gen' has no sense.")
+
+
         self.outwrap = FileWrapper(self.mgr.config.stdout,
                                    self.stdout_fd,
                                    tag='%s:out' % self.name,
@@ -1079,7 +1070,6 @@ class Subprocess(Task):
 #        self.tini = time.time() # lo hace run_task
 
         if self.shell:
-#            cmd = ('/bin/bash -c \"%s\"' % self.cmd.replace('\"', '\\"')).split()
             cmd = ['/bin/bash', '-c', "%s" % self.cmd]
         else:
             cmd = self.cmd.split()
@@ -1088,16 +1078,17 @@ class Subprocess(Task):
 #        cmd = 'setsid /bin/sh -c \"%s\"' % self.cmd.replace('\"', '\\"')
 #        cmd = self.cmd
         try:
-            self.ps = subp.Popen(cmd,
-                                 close_fds  = True,
-                                 stdin      = subp.PIPE,
-                                 stdout     = subp.PIPE,
-                                 stderr     = subp.PIPE,
-                                 shell      = False,
-                                 bufsize    = 0,
-                                 cwd        = self.cwd,
-                                 env        = self.env,
-                                 preexec_fn = os.setsid)
+            self.ps = subp.Popen(
+                cmd,
+                close_fds  = True,
+                stdin      = subp.PIPE,
+                stdout     = subp.PIPE,
+                stderr     = subp.PIPE,
+                shell      = False,
+                bufsize    = 0,
+                cwd        = self.cwd,
+                env        = self.env,
+                preexec_fn = os.setsid)
         except OSError, e:
             self.log.error("%s: '%s'" % (e, self.cmd))
             self.result = ERROR
@@ -1165,18 +1156,27 @@ class Subprocess(Task):
         if n is None:
             n = self.signal
 
+        self.log.debug("sending signal %s" % n)
+
         try:
             os.killpg(self.ps.pid, n)
         except OSError, e:
+            if e.errno == 3: return # OSError(3, 'No such process')
             Log.debug("%s (%s)" % (e, self.ps.pid))
         except AttributeError:
             self.log.warning("did not even starts")
             return
 
+        tini = time.time()
         while 1:
-            if self.ps.poll() is not None: return
+            if self.ps.poll() is not None: break
             time.sleep(0.5)
 
+            if (time.time() - tini) > 5:
+                self.log.warning('is still alive after 5 seconds!')
+                self.kill(signal.SIGKILL)
+
+
     def close(self):
         if not self.ps: return
         self.ps.stdin.close()
@@ -1186,18 +1186,20 @@ class Subprocess(Task):
 
 
 class Test(Subprocess, Public):
-    pass
+    acro = 'Test'
 
 
 class TestFunc(Task, Public):
-
-    allows = ['cwd', 'delay', 'desc', 'expected', 'must_fail', 'template', 'tid']
+    acro = 'Func'
+    allows = ['delay', 'desc', 'expected', 'must_fail', 'template', 'tid']
 
     def __init__(self, func, args=(), **kargs):
         assert callable(func)
         self.func = func
         self.args = args
-        self.check = True
+
+        if not kargs.has_key('desc'):
+            kargs['desc'] = "%s(%s)" % (func.__name__, str(self.args))
 
         Task.__init__(self, **kargs)
 
@@ -1207,9 +1209,6 @@ class TestFunc(Task, Public):
         sys.stderr = self.errwrap
 
         try:
-            current = os.getcwd()
-            if self.cwd: os.chdir(self.cwd)
-
             self.retcode = self.func(*self.args)
 
             if not isinstance(self.retcode, int):
@@ -1221,27 +1220,28 @@ class TestFunc(Task, Public):
                 self.result = (self.retcode == self.expected)
 
         except Exception, e:
-            self.log.info(e)
+            self.log.error(e)
             self.result = ERROR
 
         finally:
             sys.stdout = sys.__stdout__
             sys.stderr = sys.__stderr__
 
-        if self.cwd: os.chdir(current)
 
         if self.must_fail and self.result == FAIL:
             self.result = OK
 
 
 class Command(Subprocess, Public):
+    acro = 'Cmnd'
+
     def __init__(self, cmd, **kargs):
         Subprocess.__init__(self, cmd, **kargs)
         self.check = False
 
 
 class CompositeTask(Task, Public):
-
+    acro = 'Comp'
     allows = ['detach']
 
     """ The CompositeTask let you specify a predicate to evalue a set of tasks:
@@ -1287,17 +1287,18 @@ task_attrs = SortedDict({
     'delay':       Record(type_=int,  default=0),
     'desc':        Record(type_=str,  default=''),
     'detach':      Record(type_=bool, default=False),
+    'dirty':       Record(type_=bool, default=False),
     'env':         Record(type_=dict, default=os.environ.copy()),
     'expected':    Record(type_=int,  default=0),
     'must_fail':   Record(type_=bool, default=False),
     'parent':      Record(type_=CompositeTask, default=None),
     'path':        Record(type_=str,  default=''),
     'template':    Record(type_=list, default=[]),
-    'timeout':     Record(type_=int,  default=DFL_TIMEOUT),
+    'timeout':     Record(type_=int,  default=5),
     'save_stderr': Record(type_=bool, default=False),
     'save_stdout': Record(type_=bool, default=False),
     'shell':       Record(type_=bool, default=False),
-    'signal':      Record(type_=int,  default=DFL_SIGNAL),
+    'signal':      Record(type_=int,  default=signal.SIGKILL),
     'stderr':      Record(type_=str,  default=''),
     'stdout':      Record(type_=str,  default=''),
     'todo':        Record(type_=bool, default=False),
@@ -1306,6 +1307,7 @@ task_attrs = SortedDict({
 
 
 class Daemon(Command):
+    acro = 'Daem'
     forbid = ['timeout', 'detach', 'expected']
 
     def __init__(self, cmd, **kargs):
@@ -1387,9 +1389,14 @@ def run_task(task, keep_going=False, recurse=False, end_callback=lambda:None):
     return task.result
 
 
-class TestCase(object):
+#class ExecEnv(dict):
+#    def __init__(self, fname):
+#        self['__file__'] = fname
+
+
+class TaskCase(object):
     def __init__(self, fname, mgr, template={}):
-        fname = compath(fname)
+        fname = os.path.abspath(fname)
         self.fname = fname
         self.mgr = mgr
         self.ts = mgr.ts
@@ -1397,27 +1404,28 @@ class TestCase(object):
         aux_fname = os.path.splitext(compath(fname))[0]
 
         self.template = template
-        testdir =  os.path.dirname(fname)
+        self.testdir =  os.path.abspath(os.path.dirname(fname))
         self.template.update({
                 'basedir':  compath(),
-                'dirname':  compath(testdir),
+                'fullbasedir':  os.path.abspath(compath()),
+                'testdir':  compath(self.testdir),
+                'fulltestdir':  os.path.abspath(compath(self.testdir)),
+                'dirname':  " ERROR: ['$dirname' is deprecated: use '$testdir' instead] ",
                 'fname':    aux_fname,
                 'testname': os.path.basename(aux_fname),
                 'atheist':  './athcmd.py'})
 
-
-        #for i in self.ts[:]: self.ts.remove(i)  # empty the list :-S
         del self.ts[:]
 
-        if not self.mgr.config.skip_setup:
-            setup = os.path.join(testdir, SETUP)
-            if os.path.exists(setup ):
+        if not self.mgr.config.skip_hooks:
+            setup = os.path.join(self.testdir, SETUP)
+            if os.path.exists(setup):
                 self.process_file(setup, task_mode.SETUP)
 
         self.process_file(fname, task_mode.MAIN)
 
-        if not self.mgr.config.skip_setup:
-            teardown = os.path.join(testdir, TEARDOWN)
+        if not self.mgr.config.skip_hooks:
+            teardown = os.path.join(self.testdir, TEARDOWN)
             if os.path.exists(teardown):
                 self.process_file(teardown, task_mode.TEARDOWN)
 
@@ -1431,76 +1439,28 @@ class TestCase(object):
 #                    self.ts.remove(j)
 
         self.tasks = self.ts[:]
-
         self.result = NOEXEC
 
+    def __str__(self):
+        return "<TaskCase %s:%s>" % (self.fname, self.result)
+
 
     def process_file(self, fname, mode):
         Log.debug("%s loading" % compath(fname))
 
-        # ---
         before = self.ts[:]
         env = self.mgr.exec_env.copy()
         env['ts'] = self.ts
         env['__file__'] = os.path.abspath(fname)
 
-        try:
-            exec(self.load_file(fname)) in env
-        except Exception, e:
-            print_exc(traceback.format_exc())
-            Log.error("Errors in the task definition '%s'" % fname)
-            sys.exit(1)
+        exec_file(fname, env, None, self.template)
 
-        for t in [x for x in self.ts if x not in before]:
+        for t in set(self.ts) - set(before):
             t.fname = fname
-        # ---
-
-        for t in self.ts:
-#            if t.mode is None: t.mode = mode
             t.set_mode(mode)
 
 
-
-    def load_file(self, fname):
-        def include_error(n, line):
-            Log.error("Syntax error in: '%s:%s'" % (fname, n+1))
-            Log.error("               : %s" % line)
-
-        script = open(fname)
-        lines = [string.Template(x).safe_substitute(self.template) \
-                     for x in script.readlines()]
-        script.close()
-
-        for n, line in enumerate(lines):
-            if not line.startswith('include('): continue
-
-            #print '-', line
-            indx = lines.index(line)
-            #print indx
-            lines.remove(line)
-
-            try:
-                line = line.strip()
-                included_file = INCLUDE_RE.match(line).group(1)
-            except AttributeError:
-                include_error(n, line)
-                sys.exit(1)
-
-            try:
-                Log.debug("included file: '%s'" % included_file)
-                fd = open(included_file)
-                ilines = fd.readlines()
-                fd.close()
-                lines[indx:indx] = ilines
-            except IOError, e:
-                include_error(n, line)
-                Log.error(e)
-                sys.exit(1)
-
-        return str.join('', lines)
-
-
-    def run(self, ob):
+    def run(self, ob=lambda:None):
         Log.info("Test case %s" % (compath(self.fname)+' ').ljust(80, '-'))
 
         if not self.tasks:
@@ -1540,7 +1500,6 @@ class TestCase(object):
         if daemons:
             Log.debug("-- Killing remaining daemons...")
             for t in daemons:
-                Log.debug("sending signal %s to %s" % (t.signal, t.name))
                 t.kill()
                 t.thread.join(1)
 
@@ -1552,7 +1511,10 @@ class TestCase(object):
 
         for t in self.tasks:
             if t.result == NOEXEC: continue
-            generated.extend(remove_dups(t.gen))
+            if self.mgr.config.clean and t.dirty:
+                t.log.warning("dirty-task, not removing gen: %s" % t.gen)
+            else:
+                generated.extend(t.gen)
 
         if not generated:
             return
@@ -1561,6 +1523,8 @@ class TestCase(object):
             clean_generated(generated)
         else:
             self.create_gen_list(generated)
+            for fname in generated:
+                Log.warning("dirty-mode: not removing '%s'" % fname)
 
 
     def create_gen_list(self, filelist):
@@ -1568,6 +1532,7 @@ class TestCase(object):
         gen_fname = os.path.join(ATHEIST_TMP, '%s_%s.gen' % (gen_fname, os.getpid()))
         gen_fd = open(gen_fname, 'w')
         filelist.append(gen_fname)
+        filelist = remove_dups(filelist)
         Log.debug("Storing generated files in %s:\n%s" % (gen_fname, filelist))
         gen_fd.writelines([x+'\n' for x in filelist])
         gen_fd.flush()
@@ -1585,7 +1550,7 @@ class task_mode:
 
 def clean_generated(filelist=None):
 
-    if filelist is None:
+    if filelist is None: # borrar todo lo generado por atheist
         filelist = []
         for fname in glob.glob('/tmp/atheist/*.gen'):
             Log.debug("reading generated files from '%s'" % fname)
@@ -1620,63 +1585,11 @@ def clean_generated(filelist=None):
             Log.warning("%s is not a file nor directory!" % compath(f))
 
 
-#def clean_generated(list_fname=None):
-#    "remove generated files"
-#    basedir = compath()
-#
-#    if list_fname:
-#        files = [list_fname]
-#    else:
-#        files = glob.glob('/tmp/atheist/*.gen')
-#
-#    delfiles = []
-#    for fname in files:
-#        Log.debug("reading generated files from '%s'" % fname)
-#
-#        try:
-#            fd = open(fname)
-#            delfiles.extend(fd.readlines())
-#            fd.close()
-#        except IOError, e:
-#            Log.error(e)
-#            continue
-#
-#    #delfiles.extend(files)
-#
-#    Log.info("removing %s generated files" % len(delfiles))
-#
-#    for f in delfiles:
-#        f = f.strip('\n')
-#
-#        if not (f.startswith('/tmp') or f.startswith(basedir)):
-#            Log.warning('Removing files out of /tmp or %s is forbbiden: %s' % (basedir, f))
-#            continue
-#
-#        if os.path.isdir(f):
-#            Log.warning("- removing directory '%s'" % compath(f))
-#            os.system('rm -r %s' % f)
-#
-#        elif os.path.isfile(f):
-#            Log.debug("- removing file '%s'" % compath(f))
-#            try:
-#                os.remove(f)
-#            except OSError, e:
-#                Log.debug(e)
-#        else:
-#            Log.warning("%s is not a file nor directory!" % compath(f))
-
 
 # globals
-usercfg = IniParser(ATHEIST_CFG)  # FIXME: debería tenerlo el manager
-Log = logging.getLogger('atheist')
+usercfg = IniParser(ATHEIST_CFG)  # FIXME: it must be a Manager attr
 
 
-
-
-LOG_DATEFORMAT = '%d/%m/%y %H:%M:%S'
-
-VERSION = '0.'+'$Date: 2010-04-16 22:15:44 +0200 (Fri, 16 Apr 2010) $'[7:17].replace('-','')
-
 USAGE = '''atheist [options] [file|directory]
 
 atheist is a testing tool.
@@ -1690,7 +1603,7 @@ parser.add_option('-a', '--task-args', dest='task_args',
                   default='',
                   help='colon-separated options for the tasks')
 
-parser.add_option('-b', '--base-dir', dest='base_dir',
+parser.add_option('-b', '--base-dir', dest='basedir',
                   default=os.getcwd(),
                   help='set working directory')
 
@@ -1721,11 +1634,11 @@ parser.add_option('-g', '--gen-template', dest='gen_template',
                   action='store_true',
                   help='generate a taskcase file template with default values')
 
-# FIXME: probar esto
+# FIXME: test this
 parser.add_option('-i', '--report-detail', default=1, type=int,
              help='Report verbosity (0:nothing, [1:case], 2:task, 3:composite, 4:condition)')
 
-parser.add_option('-j', '--skip-setup', dest='skip_setup',
+parser.add_option('-j', '--skip-hooks', dest='skip_hooks',
                   action='store_true',
                   help='skip _setup and _teardown files')
 
@@ -1753,7 +1666,7 @@ parser.add_option('-o', '--stdout', dest='stdout',
                   help='print task stdout')
 
 # FIXME: probar esto
-parser.add_option('-p', '--plugin_dir', dest='pluginpath',
+parser.add_option('-p', '--plugin-dir', dest='pluginpath',
                   action='append', default=[],
                   help='a directory containing plugins')
 
@@ -1768,7 +1681,7 @@ parser.add_option('-s', '--script', dest='inline',
                   action='append', default=[],
                   help='specifies command line script')
 
-parser.add_option('-t', '--time-tag', dest='timetag',
+parser.add_option('-t', '--time-tag', dest='timetag', default='',
                   action='store_true',
                   help='include time info in the logs')
 
