@@ -2,19 +2,7 @@
 
 import os, re
 
-GREY =  chr(27)+'[38m'
-RED =   chr(27)+'[31m'
-PURPLE = chr(27)+'[95m'
-GREEN = chr(27)+'[32m'
-
-IRED =   chr(27)+'[1;91m'
-IGREEN = chr(27)+'[7;32m'
-
-HIGH =  chr(27)+'[1m'
-NORM =  chr(27)+'[m'
-
-BOLD =  chr(27)+'[1m'
-
+VERSION = '0.20100717'
 
 SETUP    = '_setup.test'
 TEARDOWN = '_teardown.test'
