@@ -2,8 +2,7 @@ import os
 import imp, inspect
 
 import atheist
-Log = atheist.Log
-
+from atheist.gvar import Log
 
 class Loader(object):
     def __init__(self, dname):
@@ -46,3 +45,5 @@ class Loader(object):
 
     def __iter__(self):
         return iter(self.plugins)
+
+
